import {
  BrowserRouter as Router,
  Route,
  Routes,
  NavLink,
  Navigate,
  useLocation,
  useNavigate,
} from "react-router-dom";

import WujieReact from "wujie-react";
import React, { useState } from "react";
import Home from "./pages/Home";
import React17 from "./pages/React17";
import All from "./pages/All.js";
import Button from "antd/es/button";
import ExportApp from "./pages/Export";
import { UnorderedListOutlined, CaretUpOutlined } from "@ant-design/icons";

const { bus } = WujieReact;

const subMap = {
  react17: ["home", "dialog", "location", "communication", "state"],
};

function Nav() {
  const location = useLocation();
  const navigation = useNavigate();
  const [react17Flag, setReact17Flag] = useState(
    location.pathname.includes("react7-sub")
  );

  const degrade = window.Proxy;

  // 在 xxx-sub 路由下子应用将激活路由同步给主应用，主应用跳转对应路由高亮菜单栏
  bus.$on("sub-route-change", (name, path) => {
    const mainName = `${name}-sub`;
    const mainPath = `/${name}-sub${path}`;
    const currentPath = window.location.hash.replace("#", "");
    if (currentPath.includes(mainName) && currentPath !== mainPath) {
      navigation(mainPath);
    }
  });

  const handleFlag = (name) => {
    switch (name) {
      case "react17":
        setReact17Flag(!react17Flag);
        break;
      default:
        break;
    }
  };

  return (
    <nav>
      <NavLink
        to="/home"
        className={({ isActive }) => (isActive ? "active" : "inactive")}
      >
        介绍
      </NavLink>
      <NavLink
        to="/react17"
        className={({ isActive }) => (isActive ? "active" : "inactive")}
      >
        react17<span className="alive">保活</span>
        <CaretUpOutlined
          className={react17Flag ? "main-icon active" : "main-icon"}
          onClick={() => handleFlag("react17")}
        />
      </NavLink>
      <div
        className="sub-menu"
        style={{ display: react17Flag ? "block" : "none" }}
      >
        {subMap.react17.map((item) => (
          <NavLink
            to={`/react17-sub/${item}`}
            key={item}
            className={({ isActive }) => (isActive ? "active" : "inactive")}
          >
            {item}
          </NavLink>
        ))}
      </div>
      <NavLink
        to="/exportApp"
        className={({ isActive }) => (isActive ? "active" : "inactive")}
      >
        exportApp
      </NavLink>
      <NavLink
        to="/all"
        className={({ isActive }) => (isActive ? "active" : "inactive")}
      >
        all
      </NavLink>
      <Button
        type="primary"
        className="menu-icon"
        icon={<UnorderedListOutlined />}
      ></Button>
    </nav>
  );
}

class App extends React.PureComponent {
  state = {
    active: false,
  };
  changeActive = (val) => {
    this.setState({ active: val });
  };
  render() {
    return (
      <div className="app">
        <Router>
          <div className={this.state.active ? "nav active" : "nav"}>
            <Nav />
          </div>
          <div className="content" onClick={() => this.changeActive(false)}>
            <Routes>
              <Route
                exact
                path="/home"
                element={<Home changeActive={this.changeActive} />}
              />
              <Route exact path="/react17" element={<React17 />} />
              <Route exact path="/react17-sub/:path" element={<React17 />} />
              <Route exact path="/exportApp" element={<ExportApp />} />
              <Route exact path="/all" element={<All />} />
              <Route path="*" element={<Navigate to="/home" replace />} />
            </Routes>
          </div>
        </Router>
      </div>
    );
  }
}

export default App;
